@@ -10,8 +10,7 @@ __all__ = (
 )
 
 from .array_mapper import ArrayMapper
-from .indexers import (CombinatorialIndexer, Proxy, RandomIndexer,
-                       SequentialIndexer)
+from .indexers import CombinatorialIndexer, Proxy, RandomIndexer, SequentialIndexer
 from .mapped_matrix import MappedMatrix
 from .resource_group import ResourceGroup
 from .version import version as __version__
